@@ -188,6 +188,18 @@ class SecurityValueHolder(object):
     def __neg__(self):
         return SecurityNegValueHolder(self)
 
+    def __and__(self, right):
+        return SecurityAndOperatorValueHolder(self, right)
+
+    def __rand__(self, left):
+        return SecurityAndOperatorValueHolder(left, self)
+
+    def __or__(self, right):
+        return SecurityOrOperatorValueHolder(self, right)
+
+    def __ror__(self, left):
+        return SecurityOrOperatorValueHolder(left, self)
+
     def shift(self, n):
         return SecurityShiftedValueHolder(self, n)
 
@@ -230,14 +242,14 @@ class SecurityValueHolder(object):
                 output_values[j, 0] = self.value_by_name(split_category[j][0])
 
         df = pd.DataFrame(output_values, index=total_category, columns=[name])
-
         if dummy_category:
             df.index = data.index
-            return df
         else:
             df[category_field] = df.index
             df.index = data.index
-            return df
+
+        df.dropna(inplace=True)
+        return df
 
 
 class FilteredSecurityValueHolder(SecurityValueHolder):
@@ -267,7 +279,7 @@ class FilteredSecurityValueHolder(SecurityValueHolder):
             return self.cached
         else:
             filter_value = self._filter.value
-            self.cached = self._computer.value[filter_value != 0]
+            self.cached = self._computer.value[filter_value]
             self.updated = True
             return self.cached
 
@@ -286,7 +298,9 @@ class FilteredSecurityValueHolder(SecurityValueHolder):
             return self.cached[names]
         else:
             filter_value = self._filter.value_by_names(names)
-            return self._computer.value_by_names(names)[filter_value]
+            orig_values = self._computer.value_by_names(names)
+            orig_values.where(filter_value, np.nan, inplace=True)
+            return orig_values
 
     def push(self, data):
         self._computer.push(data)
@@ -492,6 +506,18 @@ class SecurityNeOperatorValueHolder(SecurityCombinedValueHolder):
             left, right, operator.ne)
 
 
+class SecurityAndOperatorValueHolder(SecurityCombinedValueHolder):
+    def __init__(self, left, right):
+        super(SecurityAndOperatorValueHolder, self).__init__(
+            left, right, operator.__and__)
+
+
+class SecurityOrOperatorValueHolder(SecurityCombinedValueHolder):
+    def __init__(self, left, right):
+        super(SecurityOrOperatorValueHolder, self).__init__(
+            left, right, operator.__or__)
+
+
 class SecurityShiftedValueHolder(SecurityValueHolder):
 
     def __init__(self, right, n):
@@ -506,6 +532,76 @@ class SecurityShiftedValueHolder(SecurityValueHolder):
         }
 
 
+class SecurityWhereValueHolder(SecurityValueHolder):
+    def __init__(self, flag, left, right):
+
+        if not isinstance(flag, SecurityValueHolder):
+            if isinstance(flag, str):
+                self._flag = SecurityLatestValueHolder(flag)
+            else:
+                self._flag = IdentitySecurityValueHolder(flag)
+        else:
+            self._flag = copy.deepcopy(flag)
+
+        if not isinstance(left, SecurityValueHolder):
+            if isinstance(left, str):
+                self._left = SecurityLatestValueHolder(left)
+            else:
+                self._left = IdentitySecurityValueHolder(left)
+        else:
+            self._left = copy.deepcopy(left)
+
+        if not isinstance(right, SecurityValueHolder):
+            if isinstance(left, str):
+                self._right = SecurityLatestValueHolder(right)
+            else:
+                self._right = IdentitySecurityValueHolder(right)
+        else:
+            self._right = copy.deepcopy(right)
+
+        self._window = max(self._flag.window, self._left.window, self._right.window)
+        self._dependency = _merge2set(self._flag._dependency, _merge2set(
+            self._left._dependency, self._right._dependency))
+        self._returnSize = self._flag.valueSize
+        self.updated = False
+        self.cached = pd.Series()
+
+    @property
+    def symbolList(self):
+        return self._flag.symbolList
+
+    def push(self, data):
+        self._flag.push(data)
+        self._left.push(data)
+        self._right.push(data)
+        self.updated = False
+
+    @property
+    def value(self):
+        if self.updated:
+            return self.cached
+        else:
+            self.cached = self._left.value.where(self._flag.value, self._right.value)
+            self.updated = True
+            return self.cached
+
+    def value_by_name(self, name):
+        if self.updated:
+            return self.cached[name]
+        else:
+            if self._flag.value_by_name(name):
+                return self._left.value_by_name(name)
+            else:
+                return self._right.value_by_name(name)
+
+    def value_by_names(self, names):
+        if self.updated:
+            return self.cached[names]
+        else:
+            return self._left.value_by_names(names).where(self._flag.value_by_names(names),
+                                                          self._right.value_by_names(names))
+
+
 def dependencyCalculator(*args):
     res = defaultdict(list)
     tmp = {}
