@@ -70,9 +70,10 @@ class SecurityLogValueHolder(SecurityStatelessSingleValueHolder):
 
 
 class SecurityPowValueHolder(SecurityStatelessSingleValueHolder):
-    def __init__(self, dependency='x'):
+    def __init__(self, dependency='x', n=1):
         super(SecurityPowValueHolder, self).__init__(holderType=Pow,
-                                                     dependency=dependency)
+                                                     dependency=dependency,
+                                                     n=n)
 
 
 class SecuritySqrtValueHolder(SecurityStatelessSingleValueHolder):
@@ -126,4 +127,4 @@ class SecuritySimpleReturnValueHolder(SecurityStatelessSingleValueHolder):
 class SecurityLogReturnValueHolder(SecurityStatelessSingleValueHolder):
     def __init__(self, dependency='x'):
         super(SecurityLogReturnValueHolder, self).__init__(holderType=LogReturn,
-                                                           dependency=dependency)
+                                                           dependency=dependency)
\ No newline at end of file
