@@ -12,6 +12,7 @@ from copy import deepcopy
 import math
 import sys
 import numpy as np
+import pandas as pd
 from PyFin.Utilities import pyFinAssert
 
 # get the correct attribute of div
@@ -61,6 +62,24 @@ class Accumulator(object):
             self._dependency.push(data)
             return self._dependency.result()
 
+    def transform(self, data, name=None):
+        data.sort_index()
+
+        if not name:
+            name = 'transformed'
+
+        matrix_values = data.as_matrix()
+        columns = data.columns.tolist()
+
+        output_values = np.zeros(len(data))
+
+        for i, row in enumerate(matrix_values):
+            self.push({k: v for k, v in zip(columns, row)})
+            output_values[i] = self.result()
+
+        df = pd.Series(output_values, index=data.index, name=name)
+        return df
+
     @abstractmethod
     def result(self):
         raise NotImplementedError("result method is not implemented for Accumulator interface class")
@@ -90,35 +109,32 @@ class Accumulator(object):
 
     def _binary_operator(self, right, operatorHolder):
         if isinstance(right, Accumulator):
-            if self._returnSize == right.valueSize:
-                return operatorHolder(self, right)
-            elif self._returnSize == 1:
-                return operatorHolder(Identity(self, right.valueSize), right)
-        return operatorHolder(self, Identity(right, self._returnSize))
+            return operatorHolder(self, right)
+        return operatorHolder(self, Identity(right))
 
     def __add__(self, right):
         return self._binary_operator(right, AddedValueHolder)
 
     def __radd__(self, left):
-        return AddedValueHolder(self, Identity(left, self._returnSize))
+        return AddedValueHolder(self, Identity(left))
 
     def __sub__(self, right):
         return self._binary_operator(right, MinusedValueHolder)
 
     def __rsub__(self, left):
-        return MinusedValueHolder(Identity(left, self._returnSize), self)
+        return MinusedValueHolder(Identity(left), self)
 
     def __mul__(self, right):
         return self._binary_operator(right, MultipliedValueHolder)
 
     def __rmul__(self, left):
-        return MultipliedValueHolder(self, Identity(left, self._returnSize))
+        return MultipliedValueHolder(self, Identity(left))
 
     def __div__(self, right):
         return self._binary_operator(right, DividedValueHolder)
 
     def __rdiv__(self, left):
-        return DividedValueHolder(Identity(left, self._returnSize), self)
+        return DividedValueHolder(Identity(left), self)
 
     # only work for python 3
     def __truediv__(self, right):
@@ -143,10 +159,10 @@ class Accumulator(object):
     def __xor__(self, right):
         if isinstance(right, Accumulator):
             return ListedValueHolder(self, right)
-        return ListedValueHolder(self, Identity(right, 1))
+        return ListedValueHolder(self, Identity(right))
 
     def __rxor__(self, left):
-        return ListedValueHolder(Identity(left, 1), self)
+        return ListedValueHolder(Identity(left), self)
 
     def __rshift__(self, right):
         if isinstance(right, Accumulator):
@@ -180,10 +196,10 @@ class NegativeValueHolder(Accumulator):
 
     def result(self):
         res = self._valueHolder.result()
-        if self._returnSize > 1:
-            return tuple(-r for r in res)
-        else:
+        try:
             return -res
+        except TypeError:
+            return [-r for r in res]
 
 
 class ListedValueHolder(Accumulator):
@@ -207,10 +223,10 @@ class ListedValueHolder(Accumulator):
         resRight = self._right.result()
 
         if not hasattr(resLeft, '__iter__'):
-            resLeft = (resLeft,)
+            resLeft = np.array([resLeft])
         if not hasattr(resRight, '__iter__'):
-            resRight = (resRight,)
-        return tuple(resLeft) + tuple(resRight)
+            resRight = np.array([resRight])
+        return np.concatenate([resLeft, resRight])
 
 
 class TruncatedValueHolder(Accumulator):
@@ -250,9 +266,6 @@ class TruncatedValueHolder(Accumulator):
 
 class CombinedValueHolder(Accumulator):
     def __init__(self, left, right):
-        pyFinAssert(left.valueSize == right.valueSize, ValueError, "left value size {0} should be equal "
-                                                                "to right value size"
-                 .format(left.valueSize, right.valueSize))
         self._returnSize = left.valueSize
         self._left = deepcopy(left)
         self._right = deepcopy(right)
@@ -276,8 +289,7 @@ class ArithmeticValueHolder(CombinedValueHolder):
     def result(self):
         res1 = self._left.result()
         res2 = self._right.result()
-        if self._returnSize > 1:
-            return tuple(self._op(r1, r2) for r1, r2 in zip(res1, res2))
+
         return self._op(res1, res2)
 
     @property
@@ -339,37 +351,20 @@ class NeOperatorValueHolder(ArithmeticValueHolder):
 
 
 class Identity(Accumulator):
-    def __init__(self, value, n=1):
-        if isinstance(value, Accumulator):
-            pyFinAssert(value.valueSize == 1, ValueError, "Identity can't applied "
-                                                       "to value holder with value size {0} bigger than 1"
-                     .format(value.valueSize))
-            self._dependency = value._dependency
-            self._isValueHolder = True
-            self._window = value.window
-            self._containerSize = value._containerSize
-        else:
-            self._dependency = []
-            self._isValueHolder = False
-            self._window = 1
-            self._containerSize = 1
+    def __init__(self, value):
+        self._dependency = []
+        self._isValueHolder = False
+        self._window = 0
+        self._containerSize = 1
         self._value = value
-        self._returnSize = n
+        self._returnSize = 1
         self._isFull = 0
 
     def push(self, data):
-        if self._isValueHolder:
-            self._value.push(data)
+        pass
 
     def result(self):
-        if self._isValueHolder:
-            value = self._value.result()
-        else:
-            value = self._value
-        if self._returnSize == 1:
-            return value
-        else:
-            return (value,) * self._returnSize
+        return self._value
 
 
 class CompoundedValueHolder(Accumulator):
@@ -392,10 +387,10 @@ class CompoundedValueHolder(Accumulator):
     def push(self, data):
         self._left.push(data)
         values = self._left.result()
-        if hasattr(values, '__iter__'):
-            parameters = dict((name, value) for name, value in zip(self._right.dependency, values))
-        else:
+        if not hasattr(values, '__iter__'):
             parameters = {self._right.dependency: values}
+        else:
+            parameters = dict((name, value) for name, value in zip(self._right.dependency, values))
         self._right.push(parameters)
 
     def result(self):
@@ -426,17 +421,22 @@ class BasicFunction(Accumulator):
 
     def push(self, data):
         value = super(BasicFunction, self).push(data)
-        if np.any(np.isnan(value)):
-            return np.nan
+        if self._returnSize == 1:
+            if math.isnan(value):
+                return np.nan
+        else:
+            if np.any(np.isnan(value)):
+                return np.nan
         self._origValue = value
         self._isFull = 1
 
     def result(self):
-
-        if hasattr(self._origValue, '__iter__'):
-            return tuple(self._func(v) for v in self._origValue)
-        else:
+        try:
             return self._func(self._origValue)
+        except ValueError:
+            return np.nan
+        except TypeError:
+            return np.array([self._func(v) for v in self._origValue])
 
 
 class Exp(BasicFunction):
@@ -472,17 +472,21 @@ class Pow(Accumulator):
 
     def push(self, data):
         value = super(Pow, self).push(data)
-        if np.any(np.isnan(value)):
-            return np.nan
+        if self._returnSize == 1:
+            if math.isnan(value):
+                return np.nan
+        else:
+            if np.any(np.isnan(value)):
+                return np.nan
         self._origValue = value
         self._isFull = 1
 
     def result(self):
 
-        if hasattr(self._origValue, '__iter__'):
-            return tuple(v ** self.n for v in self._origValue)
-        else:
+        try:
             return self._origValue ** self.n
+        except TypeError:
+            return np.array(v ** self.n for v in self._origValue)
 
 
 class Abs(BasicFunction):
@@ -492,7 +496,17 @@ class Abs(BasicFunction):
 
 class Sign(BasicFunction):
     def __init__(self, dependency):
-        super(Sign, self).__init__(dependency, lambda x: 1 if x >= 0 else -1)
+
+        def sign(x):
+            try:
+                if x >= 0:
+                    return 1
+                else:
+                    return -1
+            except ValueError:
+                raise TypeError
+
+        super(Sign, self).__init__(dependency, sign)
 
 
 class Acos(BasicFunction):
