@@ -10,6 +10,7 @@ import functools
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingSum
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingVariance
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCountedPositive
@@ -33,11 +34,13 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityAsinValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinhValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityWhereValueHolder
 
 
 from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSQuantileSecurityValueHolder
 
 
 def CSRank(dependency):
@@ -52,6 +55,10 @@ def CSMeanAdjusted(dependency):
     return CSAverageAdjustedSecurityValueHolder(dependency)
 
 
+def CSQuantile(dependency):
+    return CSQuantileSecurityValueHolder(dependency)
+
+
 def SIGN(dependency='x'):
     return SecuritySignValueHolder(dependency)
 
@@ -80,6 +87,10 @@ def MIN(window, dependency='x'):
     return SecurityMovingMinimum(window, dependency)
 
 
+def QUANTILE(window, dependency='x'):
+    return SecurityMovingQuantile(window, dependency)
+
+
 def SUM(window, dependency='x'):
     return SecurityMovingSum(window, dependency)
 
@@ -156,6 +167,10 @@ def SHIFT(dependency, n):
     return SecurityShiftedValueHolder(dependency, n)
 
 
+def IIF(flag, left, right):
+    return SecurityWhereValueHolder(flag, left, right)
+
+
 HIGH = functools.partial(LAST, 'high')
 LOW = functools.partial(LAST, 'low')
 OPEN = functools.partial(LAST, 'open')
