@@ -13,6 +13,7 @@ from PyFin.Analysis.SecurityValueHolders import SecuritiesValues
 from PyFin.Analysis.SecurityValueHolders import dependencyCalculator
 from PyFin.Analysis.SecurityValueHolders import FilteredSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityWhereValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
@@ -37,6 +38,131 @@ class TestSecurityValueHolders(unittest.TestCase):
                                                                                             calculated[name]))
         self.checker = check_values
 
+    def testSecurityWhereValueHolder(self):
+        benchmark = SecurityLatestValueHolder(dependency='close')
+
+        testValueHolder = SecurityWhereValueHolder(benchmark > 0, benchmark, -benchmark)
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            benchmark.push(data)
+            testValueHolder.push(data)
+
+            calculated = testValueHolder.value
+
+            self.assertTrue(np.all(calculated > 0.))
+
+            for name in calculated.index:
+                rawValue = data[name][Factors.CLOSE]
+                if rawValue > 0.:
+                    self.assertAlmostEqual(rawValue, calculated[name])
+                else:
+                    self.assertAlmostEqual(-rawValue, calculated[name])
+
+    def testSecurityAndOperatorValueHolder(self):
+        benchmark = SecurityLatestValueHolder(dependency='close') > 0
+        benchmark2 = SecurityLatestValueHolder(dependency='open') > 0
+
+        testValueHolder = benchmark & benchmark2
+
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            testValueHolder.push(data)
+            calculated = testValueHolder.value
+
+            for name in calculated.index:
+                close_value = data[name][Factors.CLOSE]
+                open_value = data[name][Factors.OPEN]
+
+                if close_value > 0. and open_value > 0:
+                    self.assertTrue(calculated[name])
+                else:
+                    self.assertFalse(calculated[name])
+
+    def testSecurityOrOperatorValueHolder(self):
+        benchmark = SecurityLatestValueHolder(dependency='close') > 0
+        benchmark2 = SecurityLatestValueHolder(dependency='open') > 0
+
+        testValueHolder = benchmark | benchmark2
+
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            testValueHolder.push(data)
+            calculated = testValueHolder.value
+
+            for name in calculated.index:
+                close_value = data[name][Factors.CLOSE]
+                open_value = data[name][Factors.OPEN]
+
+                if close_value > 0. or open_value > 0:
+                    self.assertTrue(calculated[name])
+                else:
+                    self.assertFalse(calculated[name])
+
+    def testSecurityWhereValueHolderWithSymbolName(self):
+        benchmark = SecurityLatestValueHolder(dependency='close')
+
+        testValueHolder = SecurityWhereValueHolder(benchmark > 0, 'open', -benchmark)
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            benchmark.push(data)
+            testValueHolder.push(data)
+
+            calculated = testValueHolder.value
+
+            for name in calculated.index:
+                rawValue = data[name][Factors.CLOSE]
+                if rawValue > 0.:
+                    self.assertAlmostEqual(data[name][Factors.OPEN], calculated[name])
+                else:
+                    self.assertAlmostEqual(-rawValue, calculated[name])
+
+        testValueHolder = SecurityWhereValueHolder(benchmark > 0, 'open', 'close')
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            benchmark.push(data)
+            testValueHolder.push(data)
+
+            calculated = testValueHolder.value
+
+            for name in calculated.index:
+                rawValue = data[name][Factors.CLOSE]
+                if rawValue > 0.:
+                    self.assertAlmostEqual(data[name][Factors.OPEN], calculated[name])
+                else:
+                    self.assertAlmostEqual(rawValue, calculated[name])
+
+    def testSecurityWhereValueHolderWithMissingSymbol(self):
+        benchmark = SecurityLatestValueHolder(dependency='open')
+        benchmark2 = SecurityLatestValueHolder(dependency='close')
+        testValueHolder = SecurityWhereValueHolder(benchmark < 0, 'open', -benchmark2)
+
+        data = {'aapl': {'close': 2.0, 'open': 1.5},
+                'ibm': {'open': 1.7}}
+
+        benchmark.push(data)
+        benchmark2.push(data)
+        testValueHolder.push(data)
+
+        calculated = testValueHolder.value
+
+        self.assertAlmostEqual(calculated['aapl'], -data['aapl']['close'])
+        self.assertTrue(np.isnan(calculated['ibm']))
+
     def testFilteredSecurityValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close') > 0
         filtered = FilteredSecurityValueHolder(benchmark, benchmark)
@@ -71,6 +197,7 @@ class TestSecurityValueHolders(unittest.TestCase):
                             Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
             benchmark.push(data)
             filtered.push(data)
+
             try:
                 _ = filtered['aapl']
                 self.assertTrue(benchmark['aapl'])
@@ -83,6 +210,27 @@ class TestSecurityValueHolders(unittest.TestCase):
             except KeyError:
                 self.assertFalse(benchmark['ibm'])
 
+    def testFilteredSecurityValueHolderTransform(self):
+        rawHolder = SecurityLatestValueHolder(dependency='close')
+        fliterFlag = rawHolder >= 0
+        filteredHolder = rawHolder[fliterFlag]
+
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            rawHolder.push(data)
+            filteredHolder.push(data)
+
+            self.assertTrue(np.all(filteredHolder.value >= 0.))
+
+            rawValues = rawHolder.value
+            filteredValues = filteredHolder.value
+            for name in rawValues.index:
+                if rawValues[name] >= 0.:
+                    self.assertTrue(name in filteredValues)
+
     def testSecurityValueHolderIsFull(self):
         test = SecurityMovingMax(2, dependency='close')
 
@@ -709,4 +857,12 @@ class TestSecurityValueHolders(unittest.TestCase):
             index=[1, 1, 2, 2, 3, 3]
         )
 
+        expression = SecurityMovingAverage(2, 'close')
+        calculated = expression.transform(sample_data, name='new_factor')
+
+        expected = sample_data.rolling(window=2).mean()
+
+        np.testing.assert_array_almost_equal(calculated['new_factor'].values[1:],
+                                             expected['close'].values[1:])
+
 
