@@ -9,6 +9,7 @@ import unittest
 import math
 from collections import deque
 import numpy as np
+import pandas as pd
 from scipy.stats import linregress
 from PyFin.Math.Accumulators.IAccumulators import Exp
 from PyFin.Math.Accumulators.IAccumulators import Log
@@ -40,8 +41,13 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
         self.sampleClose = np.random.randn(10000)
         self.sampleRf = np.random.randn(10000)
 
-    def testAccumulatorBasic(self):
+    def testAddedNanValue(self):
+        m = Max(dependency='x')
+        m.push({'x': 10.0})
+        m.push({'x': np.nan})
+        self.assertAlmostEqual(10., m.value)
 
+    def testAccumulatorBasic(self):
         # check parameter list should not be empty
         with self.assertRaises(ValueError):
             Max(dependency=[])
@@ -441,7 +447,7 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
         mvCorr = (Average('close') ^ Sum('close')) >> Correlation(dependency=('x', 'y'))
 
         for i, close in enumerate(self.sampleClose):
-            data = {'close': close, 'open': open}
+            data = {'close': close, 'open': 1.}
             maxer.push(data)
             data2 = {'x': maxer.result()}
             ma5.push(data2)
@@ -534,12 +540,12 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
         test = TruncatedValueHolder(ma20 ^ max5, slice(1, 2))
         test.push(dict(close=10.0, open=5.0))
         test.push(dict(close=15.0, open=20.0))
-        self.assertAlmostEqual(test.result(), (20.0,), 15)
+        self.assertAlmostEqual(test.result(), [20.0], 15)
 
         test = TruncatedValueHolder(ma20 ^ max5, slice(0, -1))
         test.push(dict(close=10.0, open=5.0))
         test.push(dict(close=15.0, open=20.0))
-        self.assertAlmostEqual(test.result(), (12.5,), 15)
+        self.assertAlmostEqual(test.result(), [12.5], 15)
 
         with self.assertRaises(ValueError):
             _ = TruncatedValueHolder(ma20 ^ max5, slice(1, -2))
@@ -579,15 +585,15 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
 
         cmp = (m1 ^ m2) <= m2
         cmp.push(dict(x=1.0))
-        self.assertEqual((True, True), cmp.result())
+        np.testing.assert_array_equal([True, True], cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((False, True), cmp.result())
+        np.testing.assert_array_equal([False, True], cmp.result())
 
         cmp = m1 <= (m1 ^ m2)
         cmp.push(dict(x=1.0))
-        self.assertEqual((True, True), cmp.result())
+        np.testing.assert_array_equal([True, True], cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((True, False), cmp.result())
+        np.testing.assert_array_equal([True, False], cmp.result())
 
     def testLessOperator(self):
         m1 = Minimum('x')
@@ -601,15 +607,15 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
 
         cmp = (m1 ^ m2) < m2
         cmp.push(dict(x=1.0))
-        self.assertEqual((False, False), cmp.result())
+        np.testing.assert_array_equal([False, False], cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((True, False), cmp.result())
+        np.testing.assert_array_equal([True, False], cmp.result())
 
         cmp = m1 < (m1 ^ m2)
         cmp.push(dict(x=1.0))
-        self.assertEqual((False, False), cmp.result())
+        np.testing.assert_array_equal([False, False], cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((False, True), cmp.result())
+        np.testing.assert_array_equal([False, True], cmp.result())
 
     def testGreaterOrEqualOperator(self):
         m1 = Minimum('x')
@@ -623,15 +629,15 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
 
         cmp = (m1 ^ m2) >= m2
         cmp.push(dict(x=1.0))
-        self.assertEqual((True, True), cmp.result())
+        np.testing.assert_array_equal(np.array([True, True]), cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((False, True), cmp.result())
+        np.testing.assert_array_equal(np.array([False, True]), cmp.result())
 
         cmp = m1 >= (m1 ^ m2)
         cmp.push(dict(x=1.0))
-        self.assertEqual((True, True), cmp.result())
+        np.testing.assert_array_equal(np.array([True, True]), cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((True, False), cmp.result())
+        np.testing.assert_array_equal(np.array([True, False]), cmp.result())
 
     def testGreaterOperator(self):
         m1 = Max('x')
@@ -645,15 +651,15 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
 
         cmp = (m1 ^ m2) > m2
         cmp.push(dict(x=1.0))
-        self.assertEqual((False, False), cmp.result())
+        np.testing.assert_array_equal(np.array([False, False]), cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((True, False), cmp.result())
+        np.testing.assert_array_equal(np.array([True, False]), cmp.result())
 
         cmp = m1 > (m1 ^ m2)
         cmp.push(dict(x=1.0))
-        self.assertEqual((False, False), cmp.result())
+        np.testing.assert_array_equal(np.array([False, False]), cmp.result())
         cmp.push(dict(x=2.0))
-        self.assertEqual((False, True), cmp.result())
+        np.testing.assert_array_equal(np.array([False, True]), cmp.result())
 
     def testExpFunction(self):
         ma5 = MovingAverage(5, 'close')
@@ -851,3 +857,13 @@ class TestAccumulatorsArithmetic(unittest.TestCase):
             self.assertAlmostEqual(calculated, expected, 12, "at index {0:d}\n"
                                                              "expected:   {1:f}\n"
                                                              "calculated: {2:f}".format(i, expected, calculated))
+
+    def testAccumulatorTransform(self):
+        window = 5
+        ma5 = MovingAverage(window, 'close')
+        df = pd.DataFrame(self.sampleClose, columns=['close'])
+        res = ma5.transform(df, name='my_factor')[window-1:]
+        expected = df.rolling(window).mean()[window - 1:]['close']
+
+        self.assertEqual(res.name, 'my_factor')
+        np.testing.assert_array_almost_equal(res, expected)
